set dxpress_major_ver 1
set dxpress_minor_ver 3

set lic_test [file exists ../../../drivexpress_lic_enc.bin]
set qrd_test [info exists $::env(QUARTUS_ROOTDIR)]

echo "DrivExpress Stratix V Gen3x4 MM Peek/Poke Example Design"
echo "Macnica Americas"
echo ""
echo "To re-run after adding waveforms, type:"
echo "restart -f ; run -all"
echo ""
echo "To re-run after modifications, type:"
echo "do build_run.do"
echo ""

flush stdout

if {$lic_test == 0} {
    echo "Error: No license file drivexpress_lic_enc.bin present"
} elseif {[info exists $::env(QUARTUS_ROOTDIR)]} {
    echo "Error: Environment Variable QUARTUS_ROOTDIR is not set"
} elseif {![string match "*13.1*" [exec $::env(QUARTUS_ROOTDIR)/bin/quartus_sh --ver]]} {
    echo "Error: Incorrect Quartus II version set"
    echo "       Supported Quartus II version is 13.1"
} else {
    echo "Correct Quartus II version set"

    set os_test [lindex $tcl_platform(os) 0]
    if {$os_test == "Windows"} {
        echo "Running on Windows"
        set os_str "win"
        set dpi_name "dxpress$dxpress_major_ver$dxpress_minor_ver"
    } else {
        echo "Running on Linux"
        set os_str "linux"
        set dpi_name "libdxpress"
    }

    if [string match "*ALTERA*" [vsim -version]] {
        echo "Using ModelSim-Altera (Starter) Edition"
        set vsim_altera 1
    } else {
        echo "Using ModelSim/QuestaSim"
        set vsim_altera 0
    }
    
    if [string match "*64*" [vsim -version]] {
        set vsim_64 64
    } else {
        set vsim_64 32
    }

    if {$vsim_altera == 0} {
        set QL [pwd]/verilog_libs
        set lib_test [file isdirectory verilog_libs]
        if {$lib_test == 1} {
            echo "Simulation libaries present"
        } else {
            echo "Compiling simulation libraries"
            mkdir verilog_libs
            cd verilog_libs
            vlib     altera_ver
            vlib     lpm_ver
            vlib     sgate_ver
            vlib     altera_mf_ver
            vlib     altera_lnsim_ver
            vlib     stratixv_ver
            vlib     stratixv_hssi_ver
            vlib     stratixv_pcie_hip_ver
            vlog     $::env(QUARTUS_ROOTDIR)/eda/sim_lib/altera_primitives.v"                     -work altera_ver    
            vlog     $::env(QUARTUS_ROOTDIR)/eda/sim_lib/220model.v"                              -work lpm_ver    
            vlog     $::env(QUARTUS_ROOTDIR)/eda/sim_lib/sgate.v"                                 -work sgate_ver    
            vlog     $::env(QUARTUS_ROOTDIR)/eda/sim_lib/altera_mf.v"                             -work altera_mf_ver    
            vlog -sv $::env(QUARTUS_ROOTDIR)/eda/sim_lib/altera_lnsim.sv"                         -work altera_lnsim_ver    
            vlog     $::env(QUARTUS_ROOTDIR)/eda/sim_lib/mentor/stratixv_atoms_ncrypt.v"          -work stratixv_ver    
            vlog     $::env(QUARTUS_ROOTDIR)/eda/sim_lib/stratixv_atoms.v"                        -work stratixv_ver    
            vlog     $::env(QUARTUS_ROOTDIR)/eda/sim_lib/mentor/stratixv_hssi_atoms_ncrypt.v"     -work stratixv_hssi_ver    
            vlog     $::env(QUARTUS_ROOTDIR)/eda/sim_lib/stratixv_hssi_atoms.v"                   -work stratixv_hssi_ver    
            vlog     $::env(QUARTUS_ROOTDIR)/eda/sim_lib/mentor/stratixv_pcie_hip_atoms_ncrypt.v" -work stratixv_pcie_hip_ver
            vlog     $::env(QUARTUS_ROOTDIR)/eda/sim_lib/stratixv_pcie_hip_atoms.v"               -work stratixv_pcie_hip_ver
            cd ..
        }
    }

    set clean_test [file isdirectory sv_gen3x4]
    if {$clean_test == 0} {
        echo "Generating Qsys system, this may take a minute"

        catch {exec $::env(QUARTUS_ROOTDIR)/sopc_builder/bin/qsys-generate --simulation=VERILOG --family=stratixv sv_gen3x4.qsys}

        file copy -force ../../../drivexpress_lic_enc.bin .

        file copy -force ../../../lib/pcie_pipe_dpi_shell.v .

    } else {
        echo "Existing project files detected, skipping generation and copying"
    }

    set libraries_test [file isdirectory libraries]
    if {$libraries_test == 0} {
        mkdir libraries
        vlib       ./libraries/work
        vlib       ./libraries/width_adapter/                                                         
        vlib       ./libraries/rsp_xbar_mux/                                                          
        vlib       ./libraries/cmd_xbar_mux/                                                          
        vlib       ./libraries/cmd_xbar_demux/                                                        
        vlib       ./libraries/burst_adapter/                                                         
        vlib       ./libraries/id_router/                                                             
        vlib       ./libraries/addr_router/                                                           
        vlib       ./libraries/onchip_memory2_0_s1_translator_avalon_universal_slave_0_agent_rsp_fifo/
        vlib       ./libraries/onchip_memory2_0_s1_translator_avalon_universal_slave_0_agent/         
        vlib       ./libraries/pcie_sv_hip_avmm_0_Rxm_BAR0_translator_avalon_universal_master_0_agent/
        vlib       ./libraries/onchip_memory2_0_s1_translator/                                        
        vlib       ./libraries/pcie_sv_hip_avmm_0_Rxm_BAR0_translator/                                
        vlib       ./libraries/rst_controller/                                                        
        vlib       ./libraries/mm_interconnect_1/                                                     
        vlib       ./libraries/onchip_memory2_0/                                                      
        vlib       ./libraries/pcie_reconfig_driver_0/                                                
        vlib       ./libraries/alt_xcvr_reconfig_0/                                                   
        vlib       ./libraries/pcie_sv_hip_avmm_0/                                                    

        vmap       work                                                                   ./libraries/work/
        vmap       width_adapter                                                          ./libraries/width_adapter/                                                         
        vmap       rsp_xbar_mux                                                           ./libraries/rsp_xbar_mux/                                                          
        vmap       cmd_xbar_mux                                                           ./libraries/cmd_xbar_mux/                                                          
        vmap       cmd_xbar_demux                                                         ./libraries/cmd_xbar_demux/                                                        
        vmap       burst_adapter                                                          ./libraries/burst_adapter/                                                         
        vmap       id_router                                                              ./libraries/id_router/                                                             
        vmap       addr_router                                                            ./libraries/addr_router/                                                           
        vmap       onchip_memory2_0_s1_translator_avalon_universal_slave_0_agent_rsp_fifo ./libraries/onchip_memory2_0_s1_translator_avalon_universal_slave_0_agent_rsp_fifo/
        vmap       onchip_memory2_0_s1_translator_avalon_universal_slave_0_agent          ./libraries/onchip_memory2_0_s1_translator_avalon_universal_slave_0_agent/         
        vmap       pcie_sv_hip_avmm_0_Rxm_BAR0_translator_avalon_universal_master_0_agent ./libraries/pcie_sv_hip_avmm_0_Rxm_BAR0_translator_avalon_universal_master_0_agent/
        vmap       onchip_memory2_0_s1_translator                                         ./libraries/onchip_memory2_0_s1_translator/                                        
        vmap       pcie_sv_hip_avmm_0_Rxm_BAR0_translator                                 ./libraries/pcie_sv_hip_avmm_0_Rxm_BAR0_translator/                                
        vmap       rst_controller                                                         ./libraries/rst_controller/                                                        
        vmap       mm_interconnect_1                                                      ./libraries/mm_interconnect_1/                                                     
        vmap       onchip_memory2_0                                                       ./libraries/onchip_memory2_0/                                                      
        vmap       pcie_reconfig_driver_0                                                 ./libraries/pcie_reconfig_driver_0/                                                
        vmap       alt_xcvr_reconfig_0                                                    ./libraries/alt_xcvr_reconfig_0/                                                   
        vmap       pcie_sv_hip_avmm_0                                                     ./libraries/pcie_sv_hip_avmm_0/                                                    
        vlog -sv "sv_gen3x4/simulation/submodules/altera_merlin_width_adapter.sv"                                -work width_adapter                                                         
        vlog -sv "sv_gen3x4/simulation/submodules/altera_merlin_address_alignment.sv"                            -work width_adapter                                                         
        vlog -sv "sv_gen3x4/simulation/submodules/altera_merlin_burst_uncompressor.sv"                           -work width_adapter                                                         
        vlog -sv "sv_gen3x4/simulation/submodules/altera_merlin_arbitrator.sv"                                   -work rsp_xbar_mux                                                          
        vlog -sv "sv_gen3x4/simulation/submodules/sv_gen3x4_mm_interconnect_1_rsp_xbar_mux.sv"                   -work rsp_xbar_mux                                                          
        vlog -sv "sv_gen3x4/simulation/submodules/altera_merlin_arbitrator.sv"                                   -work cmd_xbar_mux                                                          
        vlog -sv "sv_gen3x4/simulation/submodules/sv_gen3x4_mm_interconnect_1_cmd_xbar_mux.sv"                   -work cmd_xbar_mux                                                          
        vlog -sv "sv_gen3x4/simulation/submodules/sv_gen3x4_mm_interconnect_1_cmd_xbar_demux.sv"                 -work cmd_xbar_demux                                                        
        vlog -sv "sv_gen3x4/simulation/submodules/altera_merlin_burst_adapter.sv"                                -work burst_adapter                                                         
        vlog -sv "sv_gen3x4/simulation/submodules/altera_merlin_address_alignment.sv"                            -work burst_adapter                                                         
        vlog -sv "sv_gen3x4/simulation/submodules/sv_gen3x4_mm_interconnect_1_id_router.sv"                      -work id_router                                                             
        vlog -sv "sv_gen3x4/simulation/submodules/sv_gen3x4_mm_interconnect_1_addr_router.sv"                    -work addr_router                                                           
        vlog     "sv_gen3x4/simulation/submodules/altera_avalon_sc_fifo.v"                                       -work onchip_memory2_0_s1_translator_avalon_universal_slave_0_agent_rsp_fifo
        vlog -sv "sv_gen3x4/simulation/submodules/altera_merlin_slave_agent.sv"                                  -work onchip_memory2_0_s1_translator_avalon_universal_slave_0_agent         
        vlog -sv "sv_gen3x4/simulation/submodules/altera_merlin_burst_uncompressor.sv"                           -work onchip_memory2_0_s1_translator_avalon_universal_slave_0_agent         
        vlog -sv "sv_gen3x4/simulation/submodules/altera_merlin_master_agent.sv"                                 -work pcie_sv_hip_avmm_0_Rxm_BAR0_translator_avalon_universal_master_0_agent
        vlog -sv "sv_gen3x4/simulation/submodules/altera_merlin_slave_translator.sv"                             -work onchip_memory2_0_s1_translator                                        
        vlog -sv "sv_gen3x4/simulation/submodules/altera_merlin_master_translator.sv"                            -work pcie_sv_hip_avmm_0_Rxm_BAR0_translator                                
        vlog     "sv_gen3x4/simulation/submodules/altera_reset_controller.v"                                     -work rst_controller                                                        
        vlog     "sv_gen3x4/simulation/submodules/altera_reset_synchronizer.v"                                   -work rst_controller                                                        
        vlog     "sv_gen3x4/simulation/submodules/sv_gen3x4_mm_interconnect_1.v"                                 -work mm_interconnect_1                                                     
        vlog     "sv_gen3x4/simulation/submodules/sv_gen3x4_onchip_memory2_0.v"                                  -work onchip_memory2_0                                                      
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_h.sv"                                        -work pcie_reconfig_driver_0                                                
        vlog -sv "sv_gen3x4/simulation/submodules/altpcie_reconfig_driver.sv"                                    -work pcie_reconfig_driver_0                                                
        vlog -sv "sv_gen3x4/simulation/submodules/altera_xcvr_functions.sv"                                      -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/altera_xcvr_functions.sv"                               -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/sv_xcvr_h.sv"                                                  -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/sv_xcvr_h.sv"                                           -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_resync.sv"                                            -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_resync.sv"                                     -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_h.sv"                                        -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_h.sv"                                 -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/sv_xcvr_dfe_cal_sweep_h.sv"                                    -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/sv_xcvr_dfe_cal_sweep_h.sv"                             -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig.sv"                                          -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig.sv"                                   -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_sv.sv"                                       -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_sv.sv"                                -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_cal_seq.sv"                                  -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_cal_seq.sv"                           -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xreconf_cif.sv"                                            -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xreconf_cif.sv"                                     -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xreconf_uif.sv"                                            -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xreconf_uif.sv"                                     -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xreconf_basic_acq.sv"                                      -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xreconf_basic_acq.sv"                               -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_analog.sv"                                   -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_analog.sv"                            -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_analog_sv.sv"                                -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_analog_sv.sv"                         -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xreconf_analog_datactrl.sv"                                -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xreconf_analog_datactrl.sv"                         -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xreconf_analog_rmw.sv"                                     -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xreconf_analog_rmw.sv"                              -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xreconf_analog_ctrlsm.sv"                                  -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xreconf_analog_ctrlsm.sv"                           -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_offset_cancellation.sv"                      -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_offset_cancellation.sv"               -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_offset_cancellation_sv.sv"                   -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_offset_cancellation_sv.sv"            -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_eyemon.sv"                                   -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_eyemon.sv"                            -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_eyemon_sv.sv"                                -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_eyemon_ctrl_sv.sv"                           -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_eyemon_ber_sv.sv"                            -work alt_xcvr_reconfig_0                                                   
        vlog     "sv_gen3x4/simulation/submodules/ber_reader_dcfifo.v"                                           -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/step_to_mon_sv.sv"                                             -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mon_to_step_sv.sv"                                             -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_eyemon_sv.sv"                         -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_eyemon_ctrl_sv.sv"                    -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_eyemon_ber_sv.sv"                     -work alt_xcvr_reconfig_0                                                   
        vlog     "sv_gen3x4/simulation/submodules/mentor/ber_reader_dcfifo.v"                                    -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/step_to_mon_sv.sv"                                      -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/mon_to_step_sv.sv"                                      -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_dfe.sv"                                      -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_dfe.sv"                               -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_dfe_sv.sv"                                   -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_dfe_reg_sv.sv"                               -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_dfe_cal_sv.sv"                               -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_dfe_cal_sweep_sv.sv"                         -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_dfe_cal_sweep_datapath_sv.sv"                -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_dfe_oc_cal_sv.sv"                            -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_dfe_pi_phase_sv.sv"                          -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_dfe_step_to_mon_en_sv.sv"                    -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_dfe_adapt_tap_sv.sv"                         -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_dfe_ctrl_mux_sv.sv"                          -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_dfe_local_reset_sv.sv"                       -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_dfe_cal_sim_sv.sv"                           -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_dfe_adapt_tap_sim_sv.sv"                     -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_dfe_sv.sv"                            -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_dfe_reg_sv.sv"                        -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_dfe_cal_sv.sv"                        -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_dfe_cal_sweep_sv.sv"                  -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_dfe_cal_sweep_datapath_sv.sv"         -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_dfe_oc_cal_sv.sv"                     -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_dfe_pi_phase_sv.sv"                   -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_dfe_step_to_mon_en_sv.sv"             -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_dfe_adapt_tap_sv.sv"                  -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_dfe_ctrl_mux_sv.sv"                   -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_dfe_local_reset_sv.sv"                -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_dfe_cal_sim_sv.sv"                    -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_dfe_adapt_tap_sim_sv.sv"              -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_adce.sv"                                     -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_adce.sv"                              -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_adce_sv.sv"                                  -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_adce_datactrl_sv.sv"                         -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_adce_sv.sv"                           -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_adce_datactrl_sv.sv"                  -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_dcd.sv"                                      -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_dcd.sv"                               -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_dcd_sv.sv"                                   -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_dcd_cal.sv"                                  -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_dcd_control.sv"                              -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_dcd_datapath.sv"                             -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_dcd_pll_reset.sv"                            -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_dcd_eye_width.sv"                            -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_dcd_align_clk.sv"                            -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_dcd_get_sum.sv"                              -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_dcd_cal_sim_model.sv"                        -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_dcd_sv.sv"                            -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_dcd_cal.sv"                           -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_dcd_control.sv"                       -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_dcd_datapath.sv"                      -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_dcd_pll_reset.sv"                     -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_dcd_eye_width.sv"                     -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_dcd_align_clk.sv"                     -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_dcd_get_sum.sv"                       -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_dcd_cal_sim_model.sv"                 -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_mif.sv"                                      -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_mif.sv"                               -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/sv_xcvr_reconfig_mif.sv"                                       -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/sv_xcvr_reconfig_mif_ctrl.sv"                                  -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/sv_xcvr_reconfig_mif_avmm.sv"                                  -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/sv_xcvr_reconfig_mif.sv"                                -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/sv_xcvr_reconfig_mif_ctrl.sv"                           -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/sv_xcvr_reconfig_mif_avmm.sv"                           -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_pll.sv"                                      -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_pll.sv"                               -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/sv_xcvr_reconfig_pll.sv"                                       -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/sv_xcvr_reconfig_pll_ctrl.sv"                                  -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/sv_xcvr_reconfig_pll.sv"                                -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/sv_xcvr_reconfig_pll_ctrl.sv"                           -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_soc.sv"                                      -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_cpu_ram.sv"                                  -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_direct.sv"                                   -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/sv_xrbasic_l2p_addr.sv"                                        -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/sv_xrbasic_l2p_ch.sv"                                          -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/sv_xrbasic_l2p_rom.sv"                                         -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/sv_xrbasic_lif_csr.sv"                                         -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/sv_xrbasic_lif.sv"                                             -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/sv_xcvr_reconfig_basic.sv"                                     -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_arbiter_acq.sv"                                            -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_basic.sv"                                    -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/sv_xrbasic_l2p_addr.sv"                                 -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/sv_xrbasic_l2p_ch.sv"                                   -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/sv_xrbasic_l2p_rom.sv"                                  -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/sv_xrbasic_lif_csr.sv"                                  -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/sv_xrbasic_lif.sv"                                      -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/sv_xcvr_reconfig_basic.sv"                              -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_arbiter_acq.sv"                                     -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_reconfig_basic.sv"                             -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_arbiter.sv"                                           -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_m2s.sv"                                               -work alt_xcvr_reconfig_0                                                   
        vlog     "sv_gen3x4/simulation/submodules/altera_wait_generate.v"                                        -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_csr_selector.sv"                                      -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_arbiter.sv"                                    -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_m2s.sv"                                        -work alt_xcvr_reconfig_0                                                   
        vlog     "sv_gen3x4/simulation/submodules/mentor/altera_wait_generate.v"                                 -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/alt_xcvr_csr_selector.sv"                               -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/sv_reconfig_bundle_to_basic.sv"                                -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/mentor/sv_reconfig_bundle_to_basic.sv"                         -work alt_xcvr_reconfig_0                                                   
        vlog     "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_cpu.v"                                       -work alt_xcvr_reconfig_0                                                   
        vlog     "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_cpu_reconfig_cpu_test_bench.v"               -work alt_xcvr_reconfig_0                                                   
        vlog     "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_cpu_reconfig_cpu.v"                          -work alt_xcvr_reconfig_0                                                   
        vlog     "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_cpu_mm_interconnect_0.v"                     -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_cpu_irq_mapper.sv"                           -work alt_xcvr_reconfig_0                                                   
        vlog     "sv_gen3x4/simulation/submodules/altera_reset_controller.v"                                     -work alt_xcvr_reconfig_0                                                   
        vlog     "sv_gen3x4/simulation/submodules/altera_reset_synchronizer.v"                                   -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/altera_merlin_master_translator.sv"                            -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/altera_merlin_slave_translator.sv"                             -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/altera_merlin_master_agent.sv"                                 -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/altera_merlin_slave_agent.sv"                                  -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/altera_merlin_burst_uncompressor.sv"                           -work alt_xcvr_reconfig_0                                                   
        vlog     "sv_gen3x4/simulation/submodules/altera_avalon_sc_fifo.v"                                       -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_cpu_mm_interconnect_0_addr_router.sv"        -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_cpu_mm_interconnect_0_addr_router_001.sv"    -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_cpu_mm_interconnect_0_id_router.sv"          -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_cpu_mm_interconnect_0_id_router_001.sv"      -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_cpu_mm_interconnect_0_cmd_xbar_demux.sv"     -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_cpu_mm_interconnect_0_cmd_xbar_demux_001.sv" -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/altera_merlin_arbitrator.sv"                                   -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_cpu_mm_interconnect_0_cmd_xbar_mux.sv"       -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_cpu_mm_interconnect_0_cmd_xbar_mux_001.sv"   -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_cpu_mm_interconnect_0_rsp_xbar_mux.sv"       -work alt_xcvr_reconfig_0                                                   
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_reconfig_cpu_mm_interconnect_0_rsp_xbar_mux_001.sv"   -work alt_xcvr_reconfig_0                                                   
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_stif/altpciexpav_stif_a2p_addrtrans.v"           -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_stif/altpciexpav_stif_a2p_fixtrans.v"            -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_stif/altpciexpav_stif_a2p_vartrans.v"            -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_stif/altpciexpav_stif_control_register.v"        -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_stif/altpciexpav_stif_cr_avalon.v"               -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_stif/altpciexpav_stif_cr_interrupt.v"            -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_stif/altpciexpav_stif_cr_rp.v"                   -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_stif/altpciexpav_stif_cr_mailbox.v"              -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_stif/altpciexpav_stif_p2a_addrtrans.v"           -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_stif/altpciexpav_stif_reg_fifo.v"                -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_stif/altpciexpav_stif_rx.v"                      -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_stif/altpciexpav_stif_rx_cntrl.v"                -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_stif/altpciexpav_stif_rx_resp.v"                 -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_stif/altpciexpav_stif_tx.v"                      -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_stif/altpciexpav_stif_tx_cntrl.v"                -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_stif/altpciexpav_stif_txavl_cntrl.v"             -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_stif/altpciexpav_stif_txresp_cntrl.v"            -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_stif/altpciexpav_clksync.v"                      -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_mm_128/altpciexpav128_a2p_addrtrans.v"           -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_mm_128/altpciexpav128_a2p_fixtrans.v"            -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_mm_128/altpciexpav128_a2p_vartrans.v"            -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_mm_128/altpciexpav128_clksync.v"                 -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_mm_128/altpciexpav128_control_register.v"        -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_mm_128/altpciexpav128_cr_avalon.v"               -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_mm_128/altpciexpav128_cr_interrupt.v"            -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_mm_128/altpciexpav128_cr_rp.v"                   -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_mm_128/altpciexpav128_cr_mailbox.v"              -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_mm_128/altpciexpav128_p2a_addrtrans.v"           -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_mm_128/altpciexpav128_rx.v"                      -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_mm_128/altpciexpav128_rx_cntrl.v"                -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_mm_128/altpciexpav128_fifo.v"                    -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_mm_128/altpciexpav128_rxm_adapter.v"             -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_mm_128/altpciexpav128_rx_resp.v"                 -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_mm_128/altpciexpav128_tx.v"                      -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_mm_128/altpciexpav128_tx_cntrl.v"                -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_mm_128/altpciexpav128_txavl_cntrl.v"             -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_mm_128/altpciexpav128_txresp_cntrl.v"            -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/mentor/avalon_lite/altpciexpav_lite_app.v"                     -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/altpciexpav_stif_app.v"                                        -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/altpciexpav128_app.v"                                          -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/altpcie_sv_hip_avmm_hwtcl.v"                                   -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/altpcie_sv_hip_ast_hwtcl.v"                                    -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/altpcie_hip_256_pipen1b.v"                                     -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/altpcie_rs_hip.v"                                              -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/altpcie_rs_serdes.v"                                           -work pcie_sv_hip_avmm_0                                                    
        vlog     "sv_gen3x4/simulation/submodules/altpcierd_hip_rs.v"                                            -work pcie_sv_hip_avmm_0                                                    
        vlog -sv "sv_gen3x4/simulation/submodules/altera_xcvr_functions.sv"                                      -work pcie_sv_hip_avmm_0                                                    
        vlog -sv "sv_gen3x4/simulation/submodules/sv_pcs.sv"                                                     -work pcie_sv_hip_avmm_0                                                    
        vlog -sv "sv_gen3x4/simulation/submodules/sv_pcs_ch.sv"                                                  -work pcie_sv_hip_avmm_0                                                    
        vlog -sv "sv_gen3x4/simulation/submodules/sv_pma.sv"                                                     -work pcie_sv_hip_avmm_0                                                    
        vlog -sv "sv_gen3x4/simulation/submodules/sv_reconfig_bundle_to_xcvr.sv"                                 -work pcie_sv_hip_avmm_0                                                    
        vlog -sv "sv_gen3x4/simulation/submodules/sv_reconfig_bundle_to_ip.sv"                                   -work pcie_sv_hip_avmm_0                                                    
        vlog -sv "sv_gen3x4/simulation/submodules/sv_reconfig_bundle_merger.sv"                                  -work pcie_sv_hip_avmm_0                                                    
        vlog -sv "sv_gen3x4/simulation/submodules/sv_rx_pma.sv"                                                  -work pcie_sv_hip_avmm_0                                                    
        vlog -sv "sv_gen3x4/simulation/submodules/sv_tx_pma.sv"                                                  -work pcie_sv_hip_avmm_0                                                    
        vlog -sv "sv_gen3x4/simulation/submodules/sv_tx_pma_ch.sv"                                               -work pcie_sv_hip_avmm_0                                                    
        vlog -sv "sv_gen3x4/simulation/submodules/sv_xcvr_h.sv"                                                  -work pcie_sv_hip_avmm_0                                                    
        vlog -sv "sv_gen3x4/simulation/submodules/sv_xcvr_avmm_csr.sv"                                           -work pcie_sv_hip_avmm_0                                                    
        vlog -sv "sv_gen3x4/simulation/submodules/sv_xcvr_avmm_dcd.sv"                                           -work pcie_sv_hip_avmm_0                                                    
        vlog -sv "sv_gen3x4/simulation/submodules/sv_xcvr_avmm.sv"                                               -work pcie_sv_hip_avmm_0                                                    
        vlog -sv "sv_gen3x4/simulation/submodules/sv_xcvr_data_adapter.sv"                                       -work pcie_sv_hip_avmm_0                                                    
        vlog -sv "sv_gen3x4/simulation/submodules/sv_xcvr_native.sv"                                             -work pcie_sv_hip_avmm_0                                                    
        vlog -sv "sv_gen3x4/simulation/submodules/sv_xcvr_plls.sv"                                               -work pcie_sv_hip_avmm_0                                                    
        vlog -sv "sv_gen3x4/simulation/submodules/alt_xcvr_resync.sv"                                            -work pcie_sv_hip_avmm_0                                                    
        vlog -sv "sv_gen3x4/simulation/submodules/sv_hssi_10g_rx_pcs_rbc.sv"                                     -work pcie_sv_hip_avmm_0                                                    
        vlog -sv "sv_gen3x4/simulation/submodules/sv_hssi_10g_tx_pcs_rbc.sv"                                     -work pcie_sv_hip_avmm_0                                                    
        vlog -sv "sv_gen3x4/simulation/submodules/sv_hssi_8g_rx_pcs_rbc.sv"                                      -work pcie_sv_hip_avmm_0                                                    
        vlog -sv "sv_gen3x4/simulation/submodules/sv_hssi_8g_tx_pcs_rbc.sv"                                      -work pcie_sv_hip_avmm_0                                                    
        vlog -sv "sv_gen3x4/simulation/submodules/sv_hssi_8g_pcs_aggregate_rbc.sv"                               -work pcie_sv_hip_avmm_0                                                    
        vlog -sv "sv_gen3x4/simulation/submodules/sv_hssi_common_pcs_pma_interface_rbc.sv"                       -work pcie_sv_hip_avmm_0                                                    
        vlog -sv "sv_gen3x4/simulation/submodules/sv_hssi_common_pld_pcs_interface_rbc.sv"                       -work pcie_sv_hip_avmm_0                                                    
        vlog -sv "sv_gen3x4/simulation/submodules/sv_hssi_pipe_gen1_2_rbc.sv"                                    -work pcie_sv_hip_avmm_0                                                    
        vlog -sv "sv_gen3x4/simulation/submodules/sv_hssi_pipe_gen3_rbc.sv"                                      -work pcie_sv_hip_avmm_0                                                    
        vlog -sv "sv_gen3x4/simulation/submodules/sv_hssi_rx_pcs_pma_interface_rbc.sv"                           -work pcie_sv_hip_avmm_0                                                    
        vlog -sv "sv_gen3x4/simulation/submodules/sv_hssi_rx_pld_pcs_interface_rbc.sv"                           -work pcie_sv_hip_avmm_0                                                    
        vlog -sv "sv_gen3x4/simulation/submodules/sv_hssi_tx_pcs_pma_interface_rbc.sv"                           -work pcie_sv_hip_avmm_0                                                    
        vlog -sv "sv_gen3x4/simulation/submodules/sv_hssi_tx_pld_pcs_interface_rbc.sv"                           -work pcie_sv_hip_avmm_0                                                    
        vlog -sv "sv_gen3x4/simulation/submodules/sv_xcvr_emsip_adapter.sv"                                      -work pcie_sv_hip_avmm_0                                                    
        vlog -sv "sv_gen3x4/simulation/submodules/sv_xcvr_pipe_native.sv"                                        -work pcie_sv_hip_avmm_0                                                    

        vlog -sv "pcie_pipe_dpi_shell.v"
    }

    vlog     "sv_gen3x4/simulation/sv_gen3x4.v"                                                                                                                                          
    vlog -sv "tb_sv_gen3x4.sv"

    vsim -sv_lib ../../../lib/$dpi_name -novopt -t ps -L work -L width_adapter -L rsp_xbar_mux -L cmd_xbar_mux -L cmd_xbar_demux -L burst_adapter -L id_router -L addr_router -L onchip_memory2_0_s1_translator_avalon_universal_slave_0_agent_rsp_fifo -L onchip_memory2_0_s1_translator_avalon_universal_slave_0_agent -L pcie_sv_hip_avmm_0_Rxm_BAR0_translator_avalon_universal_master_0_agent -L onchip_memory2_0_s1_translator -L pcie_sv_hip_avmm_0_Rxm_BAR0_translator -L rst_controller -L mm_interconnect_1 -L onchip_memory2_0 -L pcie_reconfig_driver_0 -L alt_xcvr_reconfig_0 -L pcie_sv_hip_avmm_0 -L altera_ver -L lpm_ver -L sgate_ver -L altera_mf_ver -L altera_lnsim_ver -L stratixv_ver -L stratixv_hssi_ver -L stratixv_pcie_hip_ver tb_sv_gen3x4
    add wave sim:/tb_sv_gen3x4/*
    
    run -all
} 
