`timescale 1 ns / 1 ps

module tb_sv_gen3x4 (
);

reg         cmd_proc_clk;
wire        cmd_proc_rst;
wire [31:0] cmd_proc_cnt;
reg         clk_50;
reg         refclk_125;
reg         pipeclk;
reg         pipeclk_250;
reg         pre_rst;
wire        fpga_rst;
wire        clk_locked_fixedclk_locked;
wire [3:0]  hip_serial_rx_in;
wire [3:0]  hip_serial_tx_out;
wire [1:0]  hip_pipe_sim_pipe_rate;
wire [4:0]  hip_pipe_sim_ltssmstate;
wire [2:0]  hip_pipe_eidleinfersel [3:0];
wire [1:0]  hip_pipe_powerdown [3:0];
wire [3:0]  hip_pipe_rxpolarity;
wire [3:0]  hip_pipe_txcompl;
wire [7:0]  hip_pipe_txdata [3:0];
wire [3:0]  hip_pipe_txdatak;
wire [3:0]  hip_pipe_txdetectrx;
wire [3:0]  hip_pipe_txelecidle;
wire [3:0]  hip_pipe_txdeemph;
wire [2:0]  hip_pipe_txmargin [3:0];
wire [3:0]  hip_pipe_txswing;
wire [3:0]  hip_pipe_phystatus;
wire [7:0]  hip_pipe_rxdata [3:0];
wire [3:0]  hip_pipe_rxdatak;
wire [3:0]  hip_pipe_rxelecidle;
wire [2:0]  hip_pipe_rxstatus [3:0];
wire [3:0]  hip_pipe_rxvalid;
wire [31:0] hip_ctrl_test_in;
wire        hip_ctrl_simu_mode_pipe;

// static

// enable simulation mode and pipe mode
assign hip_ctrl_test_in = {26'h2, 1'b0, 4'b0100, 1'b1};
assign hip_ctrl_simu_mode_pipe = 1'b1;

// dynamic

initial
begin
   clk_50 = 1'b0;
   #2;
   forever #10 clk_50 = ~clk_50;
end

initial
begin
   refclk_125 = 1'b0;
   forever #4 refclk_125 = ~refclk_125;
end

initial
begin
   pipeclk_250 = 1'b0;
   #2;
   forever #2 pipeclk_250 = ~pipeclk_250;
end

initial
begin
   cmd_proc_clk = 1'b0;
   forever #5 cmd_proc_clk = ~cmd_proc_clk;
end

initial
begin
   pre_rst = 1;
   wait (cmd_proc_clk == 1); wait (cmd_proc_clk == 0); 
   pre_rst = 0;
end 

assign fpga_rst = pre_rst ? 1'b1 : cmd_proc_rst;

always @ (*)
begin
   case(hip_pipe_sim_pipe_rate)
      2'b00: pipeclk = refclk_125;
      2'b01: pipeclk = pipeclk_250;
      2'b1x: $display("Gen3 not supported");
   endcase
end

// instantiations

// required paramter override for simulation
defparam dut.pcie_sv_hip_avmm_0.deskew_comma_hwtcl = "com_deskw";

sv_gen3x4 dut (
   .clk_50_clk(clk_50),                                     // input         
   .rst_reset_n(~fpga_rst),                                 // input         
   .refclk_125_clk(refclk_125),                             // input         
   .npor_npor(~fpga_rst),                                   // input         
   .npor_pin_perst(~fpga_rst),                              // input         
   .clk_locked_fixedclk_locked(clk_locked_fixedclk_locked), // output        
   .hip_serial_rx_in0(hip_serial_rx_in[0]),                 // input         
   .hip_serial_rx_in1(hip_serial_rx_in[1]),                 // input         
   .hip_serial_rx_in2(hip_serial_rx_in[2]),                 // input         
   .hip_serial_rx_in3(hip_serial_rx_in[3]),                 // input         
   .hip_serial_tx_out0(hip_serial_tx_out[0]),               // output        
   .hip_serial_tx_out1(hip_serial_tx_out[1]),               // output        
   .hip_serial_tx_out2(hip_serial_tx_out[2]),               // output        
   .hip_serial_tx_out3(hip_serial_tx_out[3]),               // output        
   .hip_pipe_sim_pipe_pclk_in(pipeclk),                     // input         
   .hip_pipe_sim_pipe_rate(hip_pipe_sim_pipe_rate),         // output [1:0]  
   .hip_pipe_sim_ltssmstate(hip_pipe_sim_ltssmstate),       // output [4:0]  
   .hip_pipe_eidleinfersel0(hip_pipe_eidleinfersel[0]),     // output [2:0]  
   .hip_pipe_eidleinfersel1(hip_pipe_eidleinfersel[1]),     // output [2:0]  
   .hip_pipe_eidleinfersel2(hip_pipe_eidleinfersel[2]),     // output [2:0]  
   .hip_pipe_eidleinfersel3(hip_pipe_eidleinfersel[3]),     // output [2:0]  
   .hip_pipe_powerdown0(hip_pipe_powerdown[0]),             // output [1:0]  
   .hip_pipe_powerdown1(hip_pipe_powerdown[1]),             // output [1:0]  
   .hip_pipe_powerdown2(hip_pipe_powerdown[2]),             // output [1:0]  
   .hip_pipe_powerdown3(hip_pipe_powerdown[3]),             // output [1:0]  
   .hip_pipe_rxpolarity0(hip_pipe_rxpolarity[0]),           // output        
   .hip_pipe_rxpolarity1(hip_pipe_rxpolarity[1]),           // output        
   .hip_pipe_rxpolarity2(hip_pipe_rxpolarity[2]),           // output        
   .hip_pipe_rxpolarity3(hip_pipe_rxpolarity[3]),           // output        
   .hip_pipe_txcompl0(hip_pipe_txcompl[0]),                 // output        
   .hip_pipe_txcompl1(hip_pipe_txcompl[1]),                 // output        
   .hip_pipe_txcompl2(hip_pipe_txcompl[2]),                 // output        
   .hip_pipe_txcompl3(hip_pipe_txcompl[3]),                 // output        
   .hip_pipe_txdata0(hip_pipe_txdata[0]),                   // output [7:0]  
   .hip_pipe_txdata1(hip_pipe_txdata[1]),                   // output [7:0]  
   .hip_pipe_txdata2(hip_pipe_txdata[2]),                   // output [7:0]  
   .hip_pipe_txdata3(hip_pipe_txdata[3]),                   // output [7:0]  
   .hip_pipe_txdatak0(hip_pipe_txdatak[0]),                 // output        
   .hip_pipe_txdatak1(hip_pipe_txdatak[1]),                 // output        
   .hip_pipe_txdatak2(hip_pipe_txdatak[2]),                 // output        
   .hip_pipe_txdatak3(hip_pipe_txdatak[3]),                 // output        
   .hip_pipe_txdetectrx0(hip_pipe_txdetectrx[0]),           // output        
   .hip_pipe_txdetectrx1(hip_pipe_txdetectrx[1]),           // output        
   .hip_pipe_txdetectrx2(hip_pipe_txdetectrx[2]),           // output        
   .hip_pipe_txdetectrx3(hip_pipe_txdetectrx[3]),           // output        
   .hip_pipe_txelecidle0(hip_pipe_txelecidle[0]),           // output        
   .hip_pipe_txelecidle1(hip_pipe_txelecidle[1]),           // output        
   .hip_pipe_txelecidle2(hip_pipe_txelecidle[2]),           // output        
   .hip_pipe_txelecidle3(hip_pipe_txelecidle[3]),           // output        
   .hip_pipe_txdeemph0(hip_pipe_txdeemph[0]),               // output        
   .hip_pipe_txdeemph1(hip_pipe_txdeemph[1]),               // output        
   .hip_pipe_txdeemph2(hip_pipe_txdeemph[2]),               // output        
   .hip_pipe_txdeemph3(hip_pipe_txdeemph[3]),               // output        
   .hip_pipe_txmargin0(hip_pipe_txmargin[0]),               // output [2:0]  
   .hip_pipe_txmargin1(hip_pipe_txmargin[1]),               // output [2:0]  
   .hip_pipe_txmargin2(hip_pipe_txmargin[2]),               // output [2:0]  
   .hip_pipe_txmargin3(hip_pipe_txmargin[3]),               // output [2:0]  
   .hip_pipe_txswing0(hip_pipe_txswing[0]),                 // output        
   .hip_pipe_txswing1(hip_pipe_txswing[1]),                 // output        
   .hip_pipe_txswing2(hip_pipe_txswing[2]),                 // output        
   .hip_pipe_txswing3(hip_pipe_txswing[3]),                 // output        
   .hip_pipe_phystatus0(hip_pipe_phystatus[0]),             // input         
   .hip_pipe_phystatus1(hip_pipe_phystatus[1]),             // input         
   .hip_pipe_phystatus2(hip_pipe_phystatus[2]),             // input         
   .hip_pipe_phystatus3(hip_pipe_phystatus[3]),             // input         
   .hip_pipe_rxdata0(hip_pipe_rxdata[0]),                   // input  [7:0]  
   .hip_pipe_rxdata1(hip_pipe_rxdata[1]),                   // input  [7:0]  
   .hip_pipe_rxdata2(hip_pipe_rxdata[2]),                   // input  [7:0]  
   .hip_pipe_rxdata3(hip_pipe_rxdata[3]),                   // input  [7:0]  
   .hip_pipe_rxdatak0(hip_pipe_rxdatak[0]),                 // input         
   .hip_pipe_rxdatak1(hip_pipe_rxdatak[1]),                 // input         
   .hip_pipe_rxdatak2(hip_pipe_rxdatak[2]),                 // input         
   .hip_pipe_rxdatak3(hip_pipe_rxdatak[3]),                 // input         
   .hip_pipe_rxelecidle0(hip_pipe_rxelecidle[0]),           // input         
   .hip_pipe_rxelecidle1(hip_pipe_rxelecidle[1]),           // input         
   .hip_pipe_rxelecidle2(hip_pipe_rxelecidle[2]),           // input         
   .hip_pipe_rxelecidle3(hip_pipe_rxelecidle[3]),           // input         
   .hip_pipe_rxstatus0(hip_pipe_rxstatus[0]),               // input  [2:0]  
   .hip_pipe_rxstatus1(hip_pipe_rxstatus[1]),               // input  [2:0]  
   .hip_pipe_rxstatus2(hip_pipe_rxstatus[2]),               // input  [2:0]  
   .hip_pipe_rxstatus3(hip_pipe_rxstatus[3]),               // input  [2:0]  
   .hip_pipe_rxvalid0(hip_pipe_rxvalid[0]),                 // input         
   .hip_pipe_rxvalid1(hip_pipe_rxvalid[1]),                 // input         
   .hip_pipe_rxvalid2(hip_pipe_rxvalid[2]),                 // input         
   .hip_pipe_rxvalid3(hip_pipe_rxvalid[3]),                 // input         
   .hip_ctrl_test_in(hip_ctrl_test_in),                     // input  [31:0] 
   .hip_ctrl_simu_mode_pipe(hip_ctrl_simu_mode_pipe)        // input         
);

// Instantiate DrivExpress Command Processor
CMD_PROC cmd_proc (
   .CLK     (cmd_proc_clk),        // Clock input
   .VER_RST (cmd_proc_rst),      // DPI Generated RST signal output
   .CNT     (cmd_proc_cnt));     // Total count of executed command (Queue type only) output

// Instantiate 4x DrivExpress PIPE lanes
genvar i;
generate
   for (i = 0; i <= 3; i++) begin: DE_PIPE
      PCIE_PIPE #(
         .Lane_num (i)) PCIE_L
      (
         .REF_CLK       (pipeclk),                  // input           Ref Clock
         .TX_CLK        (pipeclk),                  // input           Transmit Data
         .TX_DATA       (hip_pipe_txdata[i]),       // input  [7:0]    Data
         .TX_K          (hip_pipe_txdatak[i]),      // input           K Bits
         .TX_DETECTRX   (hip_pipe_txdetectrx[i]),   // input           Command Input Bit 6
         .TX_ELECIDLE   (hip_pipe_txelecidle[i]),   // input           Command Input Bit 5
         .TX_COMPLIANCE (hip_pipe_txcompl[i]),      // input           Command Input Bit 4
         .RX_POLARITY   (hip_pipe_rxpolarity[i]),   // input           Command Input Bit 3
         .RST_L         (~fpga_rst),                // input           Command Input Bit 2
         .POWERDN       (hip_pipe_powerdown[i]),    // input  [1:0]    Command Input Bits 1:0
         .RX_CLK        (),                         // output          Same as clock input
         .RX_DATA       (hip_pipe_rxdata[i]),       // output [7:0]    RX Data Out
         .RX_K          (hip_pipe_rxdatak[i]),      // output          RX K bits
         .RX_VALID      (hip_pipe_rxvalid[i]),      // output          Status Bit 5
         .PHY_STATUS    (hip_pipe_phystatus[i]),    // output          Status Bit 4
         .RX_ELECIDLE   (hip_pipe_rxelecidle[i]),   // output          Status Bit 3
         .RX_STATUS     (hip_pipe_rxstatus[i]),     // output [2:0]    Status Bits 2:0
         .INTERRUPTS    (4'h0)
      );                  // input  [3:0]    
   end
endgenerate

endmodule

